@@ -25,7 +25,11 @@ class fillVars(object, cl_base.glob_attr):
     def get_os_net_domain(self):
         ''' Определим домен'''
         domain=self._runos("%s hostname -d 2>&1"%self.path_env)
-        if re.search("^hostname: ",domain):
+        if not domain:
+            print _("Error:") + " " +_("Not found domain name")
+            print _("Command 'hostname -d' returns an empty value")
+            exit(1)
+        elif re.search("^hostname: ",domain):
             return "local"
         else:
             return domain
